@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import os
 import sys
 
@@ -9,12 +7,13 @@ from django.test.utils import get_runner
 
 
 def runtests():
-    os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.settings'
+    os.environ["DJANGO_SETTINGS_MODULE"] = "tests.settings"
     django.setup()
     TestRunner = get_runner(settings)
     test_runner = TestRunner()
-    failures = test_runner.run_tests(['tests'])
+    failures = test_runner.run_tests(["tests"])
     sys.exit(bool(failures))
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     runtests()
